@@ -93,7 +93,7 @@ describe 'watcher::api' do
       it 'configures watcher clients auth' do
         is_expected.to contain_watcher_config('watcher_clients_auth/username').with_value('watcher')
         is_expected.to contain_watcher_config('watcher_clients_auth/password').with_value( params[:watcher_client_password] )
-        is_expected.to contain_watcher_config('watcher_clients_auth/auth_url').with_value('http://localhost:35357/')
+        is_expected.to contain_watcher_config('watcher_clients_auth/auth_url').with_value('http://localhost:5000/')
         is_expected.to contain_watcher_config('watcher_clients_auth/auth_uri').with_value('http://localhost:5000/')
         is_expected.to contain_watcher_config('watcher_clients_auth/project_name').with_value('service')
         is_expected.to contain_watcher_config('watcher_clients_auth/project_domain_name').with_value('<SERVICE DEFAULT>')
@@ -135,6 +135,50 @@ describe 'watcher::api' do
         is_expected.to contain_watcher_config('watcher_clients_auth/keyfile').with_value( params[:watcher_client_keyfile] )
       end
     end
+
+    context 'when running watcher-api in wsgi' do
+      before do
+        params.merge!({ :service_name => 'httpd' })
+      end
+
+      let :pre_condition do
+        "include ::apache
+         include ::watcher::db
+         class { 'watcher': }
+         class { '::watcher::keystone::authtoken':
+           password => 'a_big_secret',
+         }"
+      end
+
+      it 'configures watcher-api service with Apache' do
+        is_expected.to contain_service('watcher-api').with(
+          :ensure => 'stopped',
+          :name   => platform_params[:api_service_name],
+          :enable => false,
+          :tag    => ['watcher-service',
+                      'watcher-db-manage-create_schema',
+                      'watcher-db-manage-upgrade'],
+        )
+      end
+    end
+
+    context 'when service_name is not valid' do
+      before do
+        params.merge!({ :service_name => 'foobar' })
+      end
+
+      let :pre_condition do
+        "include ::apache
+         include ::watcher::db
+         class { 'watcher': }
+         class { '::watcher::keystone::authtoken':
+           password => 'a_big_secret',
+         }"
+      end
+
+      it_raises 'a Puppet::Error', /Invalid service_name/
+    end
+
   end
 
   on_supported_os({
